@@ -15,7 +15,7 @@ from time import time
 
 @click.command()
 
-@click.argument('file_path', required=True)
+@click.argument('file_paths', default=[])
 @click.option('--save_path', default='')
 def main(file_paths, save_path=None):
     face_anonymizer(file_paths, save_path)
@@ -168,4 +168,8 @@ def face_anonymizer(img_n, save_path='', file_hook=None):
         logger.log(msg='Time taken to resolve this program instance: {0} seconds.'.format(time() - start_t), level=1)
 
 if __name__ == '__main__':
-    main()
+    # main()
+    import shlex
+    main(shlex.split(
+        '''file_path
+        --save_path '' '''))
